**
** Kelsey Shoub
** Feb 27, 2016 (June 6, 2016)
** Traffic Stops, Chapter 2
**
* Updated July 25, 2021


*cd "C:\Users\frank\Desktop\Chapter2"

*log using "Chap2_Updates_23July2017.txt", t replace 

set more off

*First, Figure 2.1 on news coverage:

clear
use dwb-keywords.dta


#delimit ;
twoway line one two three year if year>1989,
clcolor(black black black) 
clpattern(solid solid solid ) 
clwidth(thin medthick thick)
xtitle(Year) 
title()
graphregion(color(white)) 
cmiss(n)
yvarl()
xline(1999, lcolor(black))
text(300 1998.9 "NC Legislation" "passed in 1999" , placement(w))
legend(off)
xlabel(1990(5)2015)
ylabel(, nogrid)
ytitle("Number of Stories")
subtitle(, color(black) position(11) justification(left))
caption() 
;

graph export Fig2-1-dwb-in-news.png, replace width(1950)
graph export Figures_PNG\Figure2_1.png, width(1950) replace
graph export Figures_EPS\Figure2_1.eps, replace

clear 


*
*Figures
*

use "/mnt/trafficstop/ajlove/Cleaned_Data/NC_TrafficStops.dta"

rename Purpose purpose

* 
* Overtime
*

generate year = substr(StopDate,1,4)
generate temp_date = substr(StopDate,5,6)
split temp_date, p(-) destring
drop temp_date temp_date1
rename temp_date2 month
rename temp_date3 day

table year 

destring year, replace

drop if year <2002
drop if year >2020

gen age = Age if Age <100
gen age_categories = 1 if age <20
replace age_categories = 2 if age>19&age<30
replace age_categories = 3 if age>29&age<40
replace age_categories = 4 if age>39&age<50
replace age_categories = 5 if age>49&age!=.

*
* Race
*

table Race Ethnicity, format(%20.0f)

* Mutually exclusive race and ethnicity categories. 
* This is limited to those observations categori
table race2, format(%20.0f)

*
* Gender
*

table purpose gender, format(%20.0f)

*
* Drivers vs Passengers
*

table Type, format(%20.0f)

* Table 8: Stop Purposes of Passengers
tab purpose if type == 0
tab purpose race2 if type == 0,col
* Table 9: Searches 
tab PassengerSearch race2, col
* Table 10: Passenger Search
tab PassengerSearch age_categories
tab PassengerSearch gender
tab PassengerSearch Race
tab PassengerSearch Ethnicity

drop if Type == "P"

*
* Stats 1: Counts of Agencies and Officers
*

encode Agency, gen(agencyid)
egen officerid_unique = concat(agencyid OfficerId)
codebook agencyid officerid_unique


*
* Table 1: Stop Purposes of Drivers
* 

tab purpose
tab purpose race2,col

drop if purpose == 10

*
* Table 2: Driver Age and Sex
*

tab age_categories
tab gender

*
* Table 3: Race and Ethnicity 
*

table Race Ethnicity, format(%20.0f)

*
* Table 4: Mutually Exclusive Race/Ethnicity Identifier
*

tab race2

*
* Table 5: Outcomes (excluding passengers and check point stops)
*

gen action = Action
replace action = 0 if Action == 5

tab action race2, col

*
* Table 6: Physical Resistance (excluding passengers and check point stops)
*

tab EncounterForce race2, col
tab EngageForce race2, col
tab EncounterForce EngageForce
tab OfficerInjury race2 if purpos, col
tab DriverInjury race2 if purpose, col
tab OfficerInjury DriverInjury

*
* Table 7: Search Types of Drivers
*

tab SearchType race2, col

*
* Table 8: Search Basis
*

*remove spaces
replace searchbasis = subinstr(searchbasis, " ","", .)

*tab
tab searchbasis race2, col

*
* Table 9: Who and What is Searched
*

tab VehicleSearch race2, col
tab DriverSearch race2, col
tab PropertySearch race2, col


*
* Table 11: Contraband Found
*

clear
*use "C:\Users\de7566\Desktop\Book - Traffic Stops\Data\NC_TrafficStops_2002-2016_Clean_5June2017.dta"
use "/mnt/trafficstop/ajlove/Cleaned_Data/NC_TrafficStops_2002-2019_Clean.dta"

/*
rename SearchType searchtype
rename OuncesDrugs ouncesdrugs
rename PoundsDrugs poundsdrugs
rename PintsAlcohol pintsalcohol
rename GallonsAlcohol gallonsalcohol
rename DosagesDrugs dosagesdrugs
rename GramsDrugs gramsdrugs 
rename KilosDrugs kilosdrugs 
rename DollarMoney dollarmoney
rename Weapons weapons
rename DollarOther dollarother
*/ 

replace searchtype = . if searchoccur == 0 
replace ouncesdrugs = . if searchoccur == 0 
replace poundsdrugs = . if searchoccur == 0 
replace pintsalcohol = . if searchoccur == 0 
replace gallonsalcohol = . if searchoccur == 0 
replace dosagesdrugs = . if searchoccur == 0 
replace gramsdrugs = . if searchoccur == 0 
replace kilosdrugs = . if searchoccur == 0 
replace dollarmoney = . if searchoccur == 0 
replace dollarother = . if searchoccur == 0 
replace weapons = . if searchoccur == 0 

gen ouncesoccur = 1 if ouncesdrugs > 0
replace ouncesoccur = 0 if ouncesoccur == . 
replace ouncesoccur = 0 if ouncesdrugs == . 
gen poundsoccur = 1 if poundsdrugs > 0
replace poundsoccur = 0 if poundsoccur == . 
replace poundsoccur = 0 if poundsdrugs == . 
gen pintsoccur = 1 if pintsalcohol > 0
replace pintsoccur = 0 if pintsoccur == . 
replace pintsoccur = 0 if pintsalcohol == . 
gen gallonsoccur = 1 if gallonsalcohol > 0
replace gallonsoccur = 0 if gallonsoccur == . 
replace gallonsoccur = 0 if gallonsalcohol == . 
gen dosagesoccur = 1 if dosagesdrugs > 0
replace dosagesoccur = 0 if dosagesoccur == . 
replace dosagesoccur = 0 if dosagesdrugs == . 
gen gramsoccur = 1 if gramsdrugs > 0
replace gramsoccur = 0 if gramsoccur == . 
replace gramsoccur = 0 if gramsdrugs == . 
gen kilosoccur = 1 if kilosdrugs > 0
replace kilosoccur = 0 if kilosoccur == .
replace kilosoccur = 0 if kilosdrugs == . 
gen moneyoccur = 1 if dollarmoney > 0
replace moneyoccur = 1 if dollarother > 0 
replace moneyoccur = 0 if dollarmoney == .
replace moneyoccur = 0 if dollarother == .
replace moneyoccur = 0 if moneyoccur == . 
gen weaponsoccur = 1 if weapons > 0
replace weaponsoccur = 0 if weaponsoccur == .
replace weaponsoccur = 0 if weapons == .  
gen contra = 1 if ouncesoccur == 1 | poundsoccur == 1 | pintsoccur == 1 | gallonsoccur == 1 | dosagesoccur == 1 | gramsoccur == 1 | kilosoccur == 1 | moneyoccur == 1 | weaponsoccur == 1
gen notype = 1 if contraoccur == 1 & contra == . 
replace notype = 0 if notype == . 

gen drugs = 1 if ouncesoccur == 1 | poundsoccur == 1 | dosagesoccur == 1 | kilosoccur == 1 | gramsoccur == 1
replace drugs = 0 if drugs == . 
gen alcohol = 1 if pintsoccur == 1 | gallonsoccur == 1
replace alcohol = 0 if alcohol == . 

tab drugs
tab drugs if race2 == 1
tab drugs if race2 == 2
tab drugs if race2 == 3
tab alcohol 
tab alcohol if race2 == 1
tab alcohol if race2 == 2
tab alcohol if race2 == 3
tab moneyoccur
tab moneyoccur if race2 == 1
tab moneyoccur if race2 == 2
tab moneyoccur if race2 == 3
tab weaponsoccur 
tab weaponsoccur if race2 == 1
tab weaponsoccur if race2 == 2
tab weaponsoccur if race2 == 3
tab notype
tab notype if race2 == 1
tab notype if race2 == 2
tab notype if race2 == 3
tab contraoccur
tab contraoccur if race2 == 1
tab contraoccur if race2 == 2
tab contraoccur if race2 == 3

*
* Table 12: Property Seized
*

tab vehicleseized race2, col
tab personalpropertyseized race2, col
tab otherpropertyseized race2, col

*
* Table A1: Ethnicity, Race, Gender
*

tab race2 gender 

log close
cd /mnt/trafficstop/ajlove/logs/
translate chapter2_2017.smcl chapter2_2017.txt, replace
