* Derek Epp
* 2-23-2016
* Chapter 7 - Officer Patterns
*
*Updated July 25, 2021




*********
*Officer*
*********

**
** Figure 6.1 - Distributions of Stop Outcomes, by Officer
**

clear

use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"



gen citation = 1 if action == 3
replace citation = 0 if citation == . 

gen stops = 1

collapse (sum) citation stops, by(officerid)

gen citationrate = (citation/stops)*100

gsort -stops
sum citationrate if stops >= 100, d

*Citations
#delimit ;
histogram citationrate if stops >= 100, 
freq 
bcolor(black) fcolor(white)
ytitle(Frequency) 
xtitle(Citation Rate)  
graphregion(color(white)) 
ylabel(, nogrid) 
xlabel(0(20)100)
;
#delimit cr
*Figures are based on the 20,887 officers who stopped at least 100 motorists. 

graph export "Chapt7_Fig1_CitationRate.png", width(1950) replace

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

gen stops = 1
gen arrest = 1 if action == 4

collapse (sum) arrest stops, by(officerid)

gen arrestrate = (arrest/stops)*100

sum arrestrate if stops >= 100, d

*Arrests
#delimit ;
histogram arrestrate if stops >= 100, 
freq 
bcolor(black) fcolor(white)
ytitle(Frequency) 
xtitle(Arrest Rate)  
graphregion(color(white)) 
ylabel(, nogrid format(%12.0g)) 
xlabel(0(20)100)
;
#delimit cr

graph export "Chapt7_Fig1_ArrestRate.png", width(1950) replace

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

gen stops = 1

collapse (sum) searchoccur stops, by(officerid)

gen searchrate = (searchoccur/stops)*100

sum searchrate if stops >= 100, d

*Searches
#delimit ;
histogram searchrate if stops >= 100, 
freq 
bcolor(black) fcolor(white)
ytitle(Frequency) 
xtitle(Search Rate)  
graphregion(color(white)) 
ylabel(, nogrid format(%12.0g)) 
xlabel(0(20)100)
;
#delimit cr

graph export "Chapt7_Fig1_SearchRate.png", width(1950) replace

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

gen light = 1 if action == 0 | action == 1 | action == 2
replace light = 0 if light == . 

gen stops = 1

collapse (sum) light stops, by(officerid)

gen lightrate = (light/stops)*100

sum lightrate if stops >= 100, d

*Light Penalties
#delimit ;
histogram lightrate if stops >= 100, 
freq 
bcolor(black) fcolor(white)
ytitle(Frequency) 
xtitle(Light Penalty Rate)  
graphregion(color(white)) 
ylabel(, nogrid format(%12.0g)) 
;
#delimit cr

graph export "Chapt7_Fig1_LightRate.png", width(1950) replace

**
** Figure 6.2 - Citation Rates for Four Types of Stop, by Officer 
**

* 1= speeding, 2= stop, 3= impaired, 4= movement, 5= equipment, 6= regulatory, 7= seat belt, 8= investigation, 9= other vehicle 

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

gen stops = 1

gen citationspeed = 1 if action == 3 & purpose == 1
gen citationimpaired = 1 if action == 3 & purpose == 3
gen citationmovement = 1 if action == 3 & purpose == 4
gen citationbelt = 1 if action == 3 & purpose == 7 
gen speed = 1 if purpose == 1
gen impaired = 1 if purpose == 3
gen movement = 1 if purpose == 4
gen belt = 1 if purpose == 7 

collapse (sum) citationspeed citationimpaired citationmovement citationbelt speed impaired movement belt stops, by(officerid)

*sort stops
*drop any officer that is labeled unknown 

gsort -speed
gsort -impaired
gsort -movement
gsort -belt

*record values for footnote
count if speed > 100
count if impaired > 100
count if movement > 100
count if belt > 100

gen citationrate_speed = (citationspeed/speed)*100 if speed >= 100
gen citationrate_impaired = (citationimpaired/impaired)*100 if impaired >= 100
gen citationrate_movement = (citationmovement/movement)*100 if movement >= 100
gen citationrate_belt = (citationbelt/belt)*100 if belt >= 100

cumul citationrate_speed, gen(cumulspeed)
cumul citationrate_impaired, gen(cumulimpaired)
cumul citationrate_movement, gen(cumulmove)
cumul citationrate_belt, gen(cumulbelt)

stack cumulspeed citationrate_speed cumulimpaired citationrate_impaired cumulmove citationrate_movement cumulbelt citationrate_belt, into(c purpose) wide clear

*sum citationrate if stops >= 100, d
*record numbers in the figure note below

replace cumulspeed = cumulspeed*100
replace cumulimpaired = cumulimpaired*100
replace cumulmove = cumulmove*100
replace cumulbelt = cumulbelt*100

#delimit ; 
twoway (line cumulspeed purpose, sort lcolor(black))
(line cumulimpaired purpose, sort lcolor(gs7))
(line cumulmove purpose, sort lcolor(black) lpattern(dash))
(line cumulbelt purpose, sort lcolor(gs7) lpattern(dash)),
ytitle(Cumulative Percent of Officers) 
xtitle(Citation Rate)  
yline(50, lcolor(black))
ylabel(0(20)100)
graphregion(color(white)) 
legend(order(1 "Speeding" 2 "Impaired" 3 "Movement" 4 "Seat Belt"))
ylabel(, nogrid) 
;
#delimit cr
*Note: based on the 8,449 officers that stopped at least 100 motorists for speeding. The median value is 75.00 and the mean is 70.35. The standard deviation is 21.91. 

graph export "Chapt7_Fig2_CitationRates.png", width(1950) replace

**
** Figure 6.3 - Black and White Stops, by Officer
**

* 1= speeding, 2= stop, 3= impaired, 4= movement, 5= equipment, 6= regulatory, 7= seat belt, 8= investigation, 9= other vehicle 

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

gen investigatory = 1 if purpose == 5 | purpose == 6 | purpose == 7 | purpose == 8 | purpose == 9 
gen stops = 1 

gen invest_wht = 1 if investigatory == 1 & race2 == 1
gen invest_blk = 1 if investigatory == 1 & race2 == 2

collapse (sum) invest_wht invest_blk stops, by (officerid)

gsort -invest_blk

*Drop the unknown officer IDs
*drop if investigatory_blk == 27344 | investigatory_blk == 3900
drop if stops < 100

reg invest_wht invest_blk, noconst
gen equal = invest_blk*3.14
gen wht_stop_rate = invest_blk*1.23

*Investigatory
#delimit ;
twoway (scatter invest_wht invest_blk, mcolor(black)) 
(scatter equal invest_blk if equal <= 8000, connect(l) msymbol(none) lcolor(gs7) lwidth(medthick))
(scatter wht_stop_rate invest_blk , connect(l) msymbol(none) lcolor(gs7) lwidth(thin)),
ytitle(Whites Stopped)
xtitle(Blacks Stopped)  
ylabel(0(2000)8000, nogrid) 
xlabel(0(2000)8000)
graphregion(color(white)) 
legend(order(1 "Officer" 2 "Population Stop Rate" 3 "Average Rate"))
;
#delimit cr
*Note: On average, officers stop 1.16 Whites for each Black stopped.

graph export "Chapt7_Fig3_OfficerStops_Invest.png", width(1950) replace

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

gen safety = 1 if purpose == 1 | purpose == 2 | purpose == 3 | purpose == 4
gen stops = 1 

gen safe_wht = 1 if safety == 1 & race2 == 1
gen safe_blk = 1 if safety == 1 & race2 == 2

collapse (sum) safe_wht safe_blk stops, by (officerid)

*Drop the unknown officer IDs
*drop if safe_blk == 48618 | safe_blk == 3447
drop if stops < 100

reg safe_wht safe_blk, noconst
gen equal = safe_blk*3.14
gen wht_stop_rate = safe_blk*1.64

*Safety
#delimit ;
twoway (scatter safe_wht safe_blk, mcolor(black)) 
(scatter equal safe_blk, connect(l) msymbol(none) lcolor(gs7) lwidth(medthick))
(scatter wht_stop_rate safe_blk* , connect(l) msymbol(none) lcolor(gs7) lwidth(thin)),
ytitle(Whites Stopped)
xtitle(Blacks Stopped)  
ylabel(0(5000)20000, nogrid) 
xlabel(0(2000)10000)
graphregion(color(white)) 
legend(order(1 "Officer" 2 "Population Stop Rate" 3 "Average Rate"))
;
#delimit cr
*Note: On average, officers stop 1.73 Whites for each Black stopped.

graph export "Chapt7_Fig3_OfficerStops_Safety.png", width(1950) replace

**
** Figure 6.4 - Black and White Searches, by Officer
**

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"
*drop if stops_blk > 7000

gen invest = 1 if purpose == 5 | purpose == 6 | purpose == 7 | purpose == 8 | purpose == 9 

gen stops = 1
gen blk_stop_invest = 1 if race2 == 2 & invest == 1
gen wht_stop_invest = 1 if race2 == 1 & invest == 1
gen blk_search_invest = 1 if race2 == 2 & searchoccur == 1 & invest == 1
gen wht_search_invest = 1 if race2 == 1 & searchoccur == 1 & invest == 1
gen blk_search = 1 if race2 == 2 & searchoccur == 1 
gen wht_search = 1 if race2 == 1 & searchoccur == 1 

collapse (sum) stops blk_stop_invest wht_stop_invest blk_search_invest wht_search_invest blk_search wht_search, by (officerid)

drop if stops < 100
drop if blk_search < 10
drop if wht_search < 10

reg wht_search_invest blk_search_invest, noconst
gen stoprate=blk_search_invest*1.22
gen wht_search_rate = blk_search_invest*.34

*Investigatory
#delimit ;
twoway (scatter wht_search_invest blk_search_invest, mcolor(black))
(scatter stoprate blk_search_invest if stoprate <= 800, connect(l) msymbol(none) lcolor(gs7) lwidth(medthick))
(scatter wht_search_rate blk_search_invest , connect(l) msymbol(none) lcolor(gs7) lwidth(thin)),
ytitle(Whites Searched)
xtitle(Blacks Searched)  
ylabel(0(200)1000, nogrid) 
graphregion(color(white)) 
legend(order(1 "Officer" 2 "Stop Rate" 3 "Search Rate"))
;
#delimit cr
*Note: On average, officers search 0.28 Whites for each Black searched.

graph export "Chapt7_Fig4_OfficerSearch_Invest.png", width(1950) replace

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"
*drop if stops_blk > 7000

gen safety = 1 if purpose == 1 | purpose == 2 | purpose == 3 | purpose == 4  

gen stops = 1
gen blk_stop_safety = 1 if race2 == 2 & safety == 1
gen wht_stop_safety = 1 if race2 == 1 & safety == 1
gen blk_search_safety = 1 if race2 == 2 & searchoccur == 1 & safety == 1
gen wht_search_safety = 1 if race2 == 1 & searchoccur == 1 & safety == 1
gen blk_search = 1 if race2 == 2 & searchoccur == 1 
gen wht_search = 1 if race2 == 1 & searchoccur == 1 

collapse (sum) stops blk_stop_safety wht_stop_safety blk_search wht_search wht_search_safety blk_search_safety, by (officerid)

drop if stops < 100
drop if blk_search < 10
drop if wht_search < 10

reg wht_search_safety blk_search_safety, noconst
gen equal=blk_search_safety*1.64
gen wht_search_rate = blk_search_safety*0.85

*Safety
#delimit ;
twoway (scatter wht_search_safety blk_search_safety if wht_search_safety < 800, mcolor(black))
(scatter equal blk_search_safety, connect(l) msymbol(none) lcolor(gs7) lwidth(medthick))
(scatter wht_search_rate blk_search_safety , connect(l) msymbol(none) lcolor(gs7) lwidth(thin)),
ytitle(Whites Searched)
xtitle(Blacks Searched)  
ylabel(, nogrid) 
xlabel(0(200)600)
graphregion(color(white)) 
legend(order(1 "Officer" 2 "Stop Rate" 3 "Search Rate"))
;
#delimit cr
*Note: On average, officers search 1.00 Whites for each Black searched.

graph export "Chapt7_Fig4_OfficerSearch_Safety.png", width(1950) replace

**
** Figure 6.5 - Black-white Stop and Search Ratios, by Officer 
**

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"
gen stops = 1
gen blk_stop = 1 if race2 == 2 
gen wht_stop = 1 if race2 == 1
gen blk_search = 1 if race2 == 2 & searchoccur == 1
gen wht_search = 1 if race2 == 1 & searchoccur == 1

collapse (sum) blk_stop wht_stop blk_search wht_search stops searchoccur, by (officerid)

gen stoprate_blk = (blk_stop/stops)*100
gen stoprate_wht = (wht_stop/stops)*100
gen searchrate_blk = (blk_search/blk_stop)*100
gen searchrate_wht = (wht_search/wht_stop)*100

gen stopratio_bw = (stoprate_blk/stoprate_wht)
gen searchratio_bw = (searchrate_blk/searchrate_wht)

drop if stops < 100
drop if blk_search < 10
drop if wht_search < 10

drop if searchratio_bw > 5
drop if stopratio_bw > 5

reg searchratio_bw stopratio_bw
gen equal = searchratio_bw
gen rate = searchratio_bw*-0.072

#delimit ;
twoway (scatter searchratio_bw stopratio_bw, mcolor(black) msize(small))
(lfit searchratio_bw stopratio_bw, lcolor(gs9)),
ytitle(B-W Search Rate Ratio)
xtitle(B-W Stop Ratio)  
ylabel(, nogrid) 
xline(1, lcolor(black))
yline(1, lcolor(black))
graphregion(color(white)) 
legend(order(1 "Officer" 2 "Regression line"))
note()
;
#delimit cr
*Note: Based on 4,123  officers with at least 100 stops and 10 searches of black and white motorists.
*Excludes 28 officers with B-W search ratios above 5 and 126 with stop ratios above 5. Slope of 
*regression line is statistically significant at -0.072; adjusted R-squared is 0.020.

graph export "Chapt7_Fig5_StopSearches_Ratio5.png", width(1950) replace

**
** Figure 6.6 - High Disparity Officers 
**

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"
keep if purpose == 5 | purpose == 6 | purpose == 7 | purpose == 8 | purpose == 9 

gen stops = 1
gen blk_stop = 1 if race2 == 2 
gen wht_stop = 1 if race2 == 1
gen blk_search = 1 if race2 == 2 & searchoccur == 1
gen wht_search = 1 if race2 == 1 & searchoccur == 1

collapse (sum) stops searchoccur blk_stop wht_stop blk_search wht_search, by (officerid)

rename searchoccur searches

gen searchpct = (searches/stops)*100 
sum searchpct, d

*order officerid stops searches searchpct

**** NOTE: the value for searchpct in the code below is the STATEWIDE search rate

gen searchpct_blk = (blk_search/blk_stop)*100 if blk_stop >= 50 & wht_stop >= 50 & searchpct >= 6.57
gen searchpct_wht = (wht_search/wht_stop)*100 if blk_stop >= 50 & wht_stop >= 50 & searchpct >= 6.57
gen ratio_bw = searchpct_blk/searchpct_wht
**** NOTE: Record the number of "Obs." This is the first number that needs to be updated in the figure legend below. "Includes xxx officers..."
sum ratio_bw, d

gen highblkofficer = 1 if ratio_bw > 2 & ratio_bw < .
replace highblkofficer = 0 if highblkofficer == . 
replace highblkofficer = 0 if ratio_bw == . 
replace highblkofficer = 1 if searchpct_wht == 0 & searchpct >=3.41

**** NOTE: Record the number next to 1. This is the second number that needs to be updated in the figure legend below. "Of these officers, xxx have..."
tab highblkofficer

gen highwhtofficer = 1 if ratio_bw < 0.5
replace highwhtofficer = 0 if highwhtofficer == . 
replace highwhtofficer = 0 if ratio_bw == . 
replace highwhtofficer = 1 if searchpct_blk == 0 & searchpct >=3.07

**** NOTE: Record the number next to 1. This is the third number that needs to be updated in the figure legend below. "and xxx search Whites..."
tab highwhtofficer

*Now make three lines: equal, 2 to 1 and 1 to 2 based on black search rate
gen halfblackrate = searchpct_blk*0.5
gen twiceblackrate = searchpct_blk*2
gen equalblackrate = searchpct_blk
sum halfblackrate twiceblackrate equalblackrate

gen highdispofficer_bw = 1 if highblkofficer == 1
replace highdispofficer_bw = 1 if highwhtofficer == 1
replace highdispofficer_bw = 0 if highdispofficer_bw == . 

*This figure now just needs to perhaps be adjusted for the scale.
*See the command below that says "line twiceblackrate searchpct_blk if twiceblackrate < 25"
*That makes it stop at 25, not go higher on the Y scale.  That might need to be adjusted in other cases."

*Investigatory
**** NOTE: Make sure you have updated the legend with the values you recorded above. Also, make sure to update the search rate, which you recorded in Table 1
#delimit ;
twoway (scatter searchpct_wht searchpct_blk if highdispofficer_bw == 0 , mcolor(black))
(line equalblackrate searchpct_blk, lcolor(black) lwidth(medium) lpattern(solid))
(line twiceblackrate searchpct_blk if twiceblackrate < 100, lcolor(black) lwidth(thin) lpattern(solid))
(line  halfblackrate searchpct_blk , lcolor(black) lwidth(thin) lpattern(solid))
(scatter searchpct_wht searchpct_blk if highdispofficer_bw == 1, mcolor(black) msymbol(circle_hollow)),
ytitle(Percent of Whites Searched)
xtitle(Percent of Blacks Searched)  
ylabel(0(20)100, nogrid)
xlabel(0(20)100)
graphregion(color(white)) 
legend(off)
;
#delimit cr
*Note: Includes 4,616 officers with a minimum of 50 White stops, 50 Black stops, and a search rate above the department average of 3.07. The hollow circles indicate
*high disparity officers. Of these officers, 216 search Whites at more than twice the rate that they search Blacks; 1,524 officers search Blacks at more than twice the rate that
*they search Whites.

graph export "Chapt7_Fig5_HighDisparityOfficers_Invest.png", width(1950) replace

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"
keep if purpose == 1 | purpose == 2 | purpose == 3 | purpose == 4  

gen stops = 1
gen blk_stop = 1 if race2 == 2 
gen wht_stop = 1 if race2 == 1
gen blk_search = 1 if race2 == 2 & searchoccur == 1
gen wht_search = 1 if race2 == 1 & searchoccur == 1

collapse (sum) stops searchoccur blk_stop wht_stop blk_search wht_search, by (officerid)

rename searchoccur searches

gen searchpct = (searches/stops)*100 if stops >= 100
sum searchpct, d

*order uniqueofficer stops searches searchpct

**** NOTE: the value for searchpct in the code below is the STATEWIDE search rate

gen searchpct_blk = (blk_search/blk_stop)*100 if blk_stop >= 50 & wht_stop >= 50 & searchpct >= 3.73
gen searchpct_wht = (wht_search/wht_stop)*100 if blk_stop >= 50 & wht_stop >= 50 & searchpct >= 3.73
gen ratio_bw = searchpct_blk/searchpct_wht
**** NOTE: Record the number of "Obs." This is the first number that needs to be updated in the figure legend below. "Includes xxx officers..."
sum ratio_bw, d

gen highblkofficer = 1 if ratio_bw > 2 & ratio_bw < .
replace highblkofficer = 0 if highblkofficer == . 
replace highblkofficer = 0 if ratio_bw == . 
replace highblkofficer = 1 if searchpct_wht == 0 & searchpct >=3.07

**** NOTE: Record the number next to 1. This is the second number that needs to be updated in the figure legend below. "Of these officers, xxx have..."
tab highblkofficer

gen highwhtofficer = 1 if ratio_bw < 0.5
replace highwhtofficer = 0 if highwhtofficer == . 
replace highwhtofficer = 0 if ratio_bw == . 
replace highwhtofficer = 1 if searchpct_blk == 0 & searchpct >=3.07

**** NOTE: Record the number next to 1. This is the third number that needs to be updated in the figure legend below. "and xxx search Whites..."
tab highwhtofficer

*Now make three lines: equal, 2 to 1 and 1 to 2 based on black search rate
gen halfblackrate = searchpct_blk*0.5
gen twiceblackrate = searchpct_blk*2
gen equalblackrate = searchpct_blk
sum halfblackrate twiceblackrate equalblackrate

gen highdispofficer_bw = 1 if highblkofficer == 1
replace highdispofficer_bw = 1 if highwhtofficer == 1
replace highdispofficer_bw = 0 if highdispofficer_bw == . 

*This figure now just needs to perhaps be adjusted for the scale.
*See the command below that says "line twiceblackrate searchpct_blk if twiceblackrate < 25"
*That makes it stop at 25, not go higher on the Y scale.  That might need to be adjusted in other cases."

*Safety
**** NOTE: Make sure you have updated the legend with the values you recorded above. Also, make sure to update the search rate, which you recorded in Table 1
#delimit ;
twoway (scatter searchpct_wht searchpct_blk if highdispofficer_bw == 0 , mcolor(black))
(line equalblackrate searchpct_blk, lcolor(black) lwidth(medium) lpattern(solid))
(line twiceblackrate searchpct_blk if twiceblackrate < 50, lcolor(black) lwidth(thin) lpattern(solid))
(line  halfblackrate searchpct_blk , lcolor(black) lwidth(thin) lpattern(solid))
(scatter searchpct_wht searchpct_blk if highdispofficer_bw == 1, mcolor(black) msymbol(circle_hollow)),
ytitle(Percent of Whites Searched)
xtitle(Percent of Blacks Searched)  
ylabel(0(20)80, nogrid)
xlabel(0(20)80)
graphregion(color(white)) 
legend(off)
;
#delimit cr
*Note: Includes 2,880 officers with a minimum of 50 White stops, 50 Black stops, and a search rate above the department average of 3.07. The hollow circles indicate
*high disparity officers. Of these officers, 244 search Whites at more than twice the rate that they search Blacks; 889 officers search Blacks at more than twice the rate that
*they search Whites.

graph export "Chapt7_Fig5_HighDisparityOfficers_Safety.png", width(1950) replace

********
*Agency*
********

**
** Figure 6.7 - Distributions of Stop Outcomes, by Agency
**

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

gen citation = 1 if action == 3
replace citation = 0 if citation == . 

gen stops = 1

collapse (sum) citation stops, by(agencyid)

gsort -stops

gen citationrate = (citation/stops)*100

sum citationrate if stops >= 10000, d
*drop if stops < 100

*Citations
#delimit ;
histogram citationrate if stops >= 10000, 
freq 
bcolor(black) fcolor(white)
ytitle(Frequency) 
xtitle(Citation Rate)  
graphregion(color(white)) 
ylabel(, nogrid) 
xlabel(0(20)100)
;
#delimit cr
*Note: based on the 139 agencies that stopped at least 10,000 motorists.  

graph export "Chapt7_Fig7_CitationRate.png", width(1950) replace

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

gen stops = 1
*gen arrest = 1 if action == 4

collapse (sum) arrest stops, by(agencydescription)

gen arrestrate = (arrest/stops)*100

sum arrestrate if stops >= 10000, d
*drop if stops < 100

*Arrests
#delimit ;
histogram arrestrate if stops >= 10000 & arrestrate < 30, 
freq 
bcolor(black) fcolor(white)
ytitle(Frequency) 
xtitle(Arrest Rate)  
graphregion(color(white)) 
ylabel(, nogrid format(%12.0g)) 
xlabel(0(20)100)
;
#delimit cr
*Note: The arrest rate distribution excludes the Tarboro Police Department, which has an outlying rate of 40%.

graph export "Chapt7_Fig7_ArrestRate.png", width(1950) replace

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

gen stops = 1

collapse (sum) searchoccur stops, by(agencydescription)

gen searchrate = (searchoccur/stops)*100

sum searchrate if stops >= 10000, d
*drop if stops < 100

*Searches
#delimit ;
histogram searchrate if stops >= 10000, 
freq 
bcolor(black) fcolor(white)
ytitle(Frequency) 
xtitle(Search Rate)  
graphregion(color(white)) 
ylabel(, nogrid format(%12.0g)) 
xlabel(0(20)100)
;
#delimit cr
*Note: based on the 304 agencies that stopped at least 100 motorists. The median value is 2.90 and the mean is 4.92. The standard deviation is 6.20.  

graph export "Chapt7_Fig7_SearchRate.png", width(1950) replace

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

gen light = 1 if action == 0 | action == 1 | action == 2
replace light = 0 if light == . 

gen stops = 1

collapse (sum) light stops, by(agencyid)

gen lightrate = (light/stops)*100

sum lightrate if stops >= 10000, d
*drop if stops < 100

*Light Penalties
#delimit ;
histogram lightrate if stops >= 10000, 
freq 
bcolor(black) fcolor(white)
ytitle(Frequency) 
xtitle(Light Penalty Rate)  
graphregion(color(white)) 
ylabel(, nogrid format(%12.0g)) 
xlabel(0(20)100)
;
#delimit cr
*Note: based on the 304 agencies that stopped at least 100 motorists. The median value is 44.54 and the mean is 43.20. The standard deviation is 22.25.  

graph export "Chapt7_Fig7_LightRate.png", width(1950) replace

**
** Table 6.1 - High and Low Search Rate Agencies
**

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

gen stops = 1
rename searchoccur searches

collapse (sum) stops searches, by(agencyid agencydescription)

drop if stops < 10000

gen searchrate = (searches/stops)*100

format %20.0g stops 

gsort -searchrate
list searchrate stops agencydescription in 1/10
sort searchrate
list searchrate stops agencydescription in 1/10

*get totals
sum stops
display r(sum)

sum searches
display r(sum)

*hand calculate the state wide search rate

**
** Figure 6.8 - High Disparity Agencies 
**

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

keep if purpose == 5 | purpose == 6 | purpose == 7 | purpose == 8 | purpose == 9 

gen stops = 1
gen blk_stop = 1 if race2 == 2 
gen wht_stop = 1 if race2 == 1
gen blk_search = 1 if race2 == 2 & searchoccur == 1
gen wht_search = 1 if race2 == 1 & searchoccur == 1

rename searchoccur searches

collapse (sum) stops searches blk_search wht_search blk_stop wht_stop, by (agencyid)

gen searchpct = (searches/stops)*100 if stops >= 100

**** NOTE: the value for searchpct in the code below is the overall AGENCY LEVEL search rate. 

gen searchpct_blk = (blk_search/blk_stop)*100 if blk_stop >= 50 & wht_stop >= 50
gen searchpct_wht = (wht_search/wht_stop)*100 if blk_stop >= 50 & wht_stop >= 50 
gen ratio_bw = searchpct_blk/searchpct_wht
**** NOTE: Record the number of "Obs." This is the first number that needs to be updated in the figure legend below. "Includes xxx officers..."
sum ratio_bw, d

gen highblkagency = 1 if ratio_bw > 2 & ratio_bw < .
replace highblkagency = 0 if highblkagency == . 
replace highblkagency = 0 if ratio_bw == . 
replace highblkagency = 1 if searchpct_wht == 0 

**** NOTE: Record the number next to 1. This is the second number that needs to be updated in the figure legend below. "Of these officers, xxx have..."
tab highblkagency

gen highwhtagency = 1 if ratio_bw < 0.5
replace highwhtagency = 0 if highwhtagency == . 
replace highwhtagency = 0 if ratio_bw == . 
replace highwhtagency = 1 if searchpct_blk == 0 

**** NOTE: Record the number next to 1. This is the third number that needs to be updated in the figure legend below. "and xxx search Whites..."
tab highwhtagency

*Now make three lines: equal, 2 to 1 and 1 to 2 based on black search rate
gen halfblackrate = searchpct_blk*0.5
gen twiceblackrate = searchpct_blk*2
gen equalblackrate = searchpct_blk
sum halfblackrate twiceblackrate equalblackrate

gen highdispagency_bw = 1 if highblkagency == 1
replace highdispagency_bw = 1 if highwhtagency == 1
replace highdispagency_bw = 0 if highdispagency_bw == . 

*This figure now just needs to perhaps be adjusted for the scale.
*See the command below that says "line twiceblackrate searchpct_blk if twiceblackrate < 25"
*That makes it stop at 25, not go higher on the Y scale.  That might need to be adjusted in other cases."

*Investigatory
**** NOTE: Make sure you have updated the legend with the values you recorded above. Also, make sure to update the search rate, which you recorded in Table 1
#delimit ;
twoway (scatter searchpct_wht searchpct_blk if highdispagency_bw == 0 , mcolor(black))
(line equalblackrate searchpct_blk, lcolor(black) lwidth(medium) lpattern(solid))
(line twiceblackrate searchpct_blk if twiceblackrate < 50, lcolor(black) lwidth(thin) lpattern(solid))
(line  halfblackrate searchpct_blk , lcolor(black) lwidth(thin) lpattern(solid))
(scatter searchpct_wht searchpct_blk if highdispagency_bw == 1, mcolor(black) msymbol(circle_hollow)),
ytitle(Percent of Whites Searched)
xtitle(Percent of Blacks Searched)  
ylabel(0(10)40, nogrid)
graphregion(color(white)) 
legend(off)
;
#delimit cr
*Note: Includes 267 agencies with a minimum of 50 White stops and 50 Black stops. The hollow circles indicate
*high disparity agencies. Of these agencies, 45 agencies search Blacks at more than twice the rate that they search Whites; 5 agencies search Whites at more than twice the rate that
*they search Blacks.

graph export "Chapt7_Fig8_HighDisparityAgency_Invest.png", replace

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

keep if purpose == 1 | purpose == 2 | purpose == 3 | purpose == 4  

gen stops = 1
gen blk_stop = 1 if race2 == 2 
gen wht_stop = 1 if race2 == 1
gen blk_search = 1 if race2 == 2 & searchoccur == 1
gen wht_search = 1 if race2 == 1 & searchoccur == 1

rename searchoccur searches

collapse (sum) stops searches blk_search wht_search blk_stop wht_stop, by (agencyid)

gen searchpct = (searches/stops)*100 if stops >= 100
sum searchpct, d

**** NOTE: the value for searchpct in the code below is the overall AGENCY LEVEL search rate. 

gen searchpct_blk = (blk_search/blk_stop)*100 if blk_stop >= 50 & wht_stop >= 50
gen searchpct_wht = (wht_search/wht_stop)*100 if blk_stop >= 50 & wht_stop >= 50 
gen ratio_bw = searchpct_blk/searchpct_wht
**** NOTE: Record the number of "Obs." This is the first number that needs to be updated in the figure legend below. "Includes xxx officers..."
sum ratio_bw, d

gen highblkagency = 1 if ratio_bw > 2 & ratio_bw < .
replace highblkagency = 0 if highblkagency == . 
replace highblkagency = 0 if ratio_bw == . 
replace highblkagency = 1 if searchpct_wht == 0

**** NOTE: Record the number next to 1. This is the second number that needs to be updated in the figure legend below. "Of these officers, xxx have..."
tab highblkagency

gen highwhtagency = 1 if ratio_bw < 0.5
replace highwhtagency = 0 if highwhtagency == . 
replace highwhtagency = 0 if ratio_bw == . 
replace highwhtagency = 1 if searchpct_blk == 0 

**** NOTE: Record the number next to 1. This is the third number that needs to be updated in the figure legend below. "and xxx search Whites..."
tab highwhtagency

*Now make three lines: equal, 2 to 1 and 1 to 2 based on black search rate
gen halfblackrate = searchpct_blk*0.5
gen twiceblackrate = searchpct_blk*2
gen equalblackrate = searchpct_blk
sum halfblackrate twiceblackrate equalblackrate

gen highdispagency_bw = 1 if highblkagency == 1
replace highdispagency_bw = 1 if highwhtagency == 1
replace highdispagency_bw = 0 if highdispagency_bw == . 

*This figure now just needs to perhaps be adjusted for the scale.
*See the command below that says "line twiceblackrate searchpct_blk if twiceblackrate < 25"
*That makes it stop at 25, not go higher on the Y scale.  That might need to be adjusted in other cases."

*Safety
**** NOTE: Make sure you have updated the legend with the values you recorded above. Also, make sure to update the search rate, which you recorded in Table 1
#delimit ;
twoway (scatter searchpct_wht searchpct_blk if highdispagency_bw == 0 , mcolor(black))
(line equalblackrate searchpct_blk, lcolor(black) lwidth(medium) lpattern(solid))
(line twiceblackrate searchpct_blk if twiceblackrate < 60, lcolor(black) lwidth(thin) lpattern(solid))
(line  halfblackrate searchpct_blk , lcolor(black) lwidth(thin) lpattern(solid))
(scatter searchpct_wht searchpct_blk if highdispagency_bw == 1, mcolor(black) msymbol(circle_hollow)),
ytitle(Percent of Whites Searched)
xtitle(Percent of Blacks Searched)  
ylabel(, nogrid)
graphregion(color(white)) 
legend(off)
;
#delimit cr
*Note: Includes 254 agencies with a minimum of 50 White stops and 50 Black stops.. The hollow circles indicate
*high disparity agencies. Of these agencies, 53 agencies search Blacks at more than twice the rate that they search Whites; 11 agencies search Whites at more than twice the rate that
*they search Blacks.

graph export "Chapt7_Fig8_HighDisparityAgency_Safety.png", width(1950) replace

**
** Figure 7.9 - Percent of Stops that are Investigatory, Agency (ALTERNATE)
**

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

*drop if stops_blk > 7000

gen investigatory = 1 if purpose == 5 | purpose == 6 | purpose == 7 | purpose == 8 | purpose == 9 
gen stops_blk = 1 if race2 == 2 
gen stops_wht = 1 if race2 == 1
gen stops_tot = 1
gen investigatory_blk = 1 if investigatory == 1 & race2 == 2
gen investigatory_wht = 1 if investigatory == 1 & race2 == 1

collapse (sum) investigatory_blk stops_blk investigatory_wht stops_wht stops_tot, by(agencyid)

drop if stops_blk < 50
drop if stops_wht < 50

gen pctinvest_blk = (investigatory_blk/stops_blk)*100
sum pctinvest_blk if stops_tot >= 100, d

gen pctinvest_wht = (investigatory_wht/stops_wht)*100
sum pctinvest_wht if stops_tot >= 100, d

cumul pctinvest_wht, gen(cumwht)
cumul pctinvest_blk, gen(cumblk)

stack cumwht pctinvest_wht cumblk pctinvest_blk, into(c race) wide clear

replace cumwht = cumwht*100
replace cumblk = cumblk*100

#delimit ; 
twoway (line cumwht race, sort lcolor(black))
(line cumblk race, sort lcolor(gs7) lpattern(dash)),
ytitle(Cumulative Percent of Agencies) 
xtitle(Percent Investigatory Stops)  
yline(50, lcolor(black))
graphregion(color(white)) 
legend(order(1 "White" 2 "Black"))
ylabel(, nogrid) 
;
#delimit cr

graph export "Chapt7_Fig8_CumulativePlots.png", width(1950) replace


