*Derek Epp (and Kelsey Shoub)
*5-4-2016 (6/3/2016)
*Traffic Stops Book 
*Chapter 8 - Hispanics
*
*Updated July 25, 2020

cd "C:\Users\f002ddt\Desktop\Book - Traffic Stops\Chapter 8 - Hispanics"

*log using Chap8_Hispanics_3June2016.txt, t replace

**
** Table 7.1 -- White, Black, and Hispanic Traffic Stops Compared
**

tab purpose race2 if gender == 0, row
tab purpose race2 if gender == 1, row

**
** Table 7.2 -- Relative Frequencies of White, Black, and Hispanic Stops, by Purpose
**

*** Composition table; no do-file code ***

** 
** Figure 7.1 - Outcome Rates by Race, Gender, and Age Group 
**

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

gen RG4 = .
replace RG4=1 if gender == 1 & race2 == 3
replace RG4=2 if gender == 1 & race2 == 1
replace RG4=3 if gender == 0 & race2 == 3
replace RG4=4 if gender == 0 & race2 == 1
label variable RG4 "Race and Gender"
label define RG4 1 "Hispanic Male" 2 "White Male" 3 "Hispanic Female" 4 "White Female"

gen agerange = .
replace agerange = 1 if age<20
replace agerange = 2 if age>19
replace agerange = 3 if age>24
replace agerange = 4 if age>29
replace agerange = 5 if age>34
replace agerange = 6 if age>39
replace agerange = 7 if age>49
replace agerange = . if age == .
label variable agerange "Age Group"
label define agerange 1 "Less Than 20" 2 "20-24" 3 "25-29" 4 "30-34" 5 "35-39" 6 "40-49" 7 "50+"

tab1 RG4 agerange

gen RGAge = (RG4*10)+agerange

gen stops = 1
gen noaction = 1 if action == 0
replace noaction = 0 if noaction == . 
gen verbal = 1 if action == 1
replace verbal = 0 if verbal == . 
gen written = 1 if action == 2
replace written = 0 if written == .
gen citation = 1 if action == 3
replace citation = 0 if citation == . 

rename searchoccur searches

*gen arrest = 1 if action == 4

collapse (min) RG4 agerange (sum) stops searches noaction verbal written citation arrest, by(RGAge)

gen searchrate = (searches*100)/stops
gen noactionrate = (noaction*100)/stops
gen verbalrate = (verbal*100)/stops
gen writtenrate = (written*100)/stops
gen citationrate = (citation*100)/stops
gen arrestrate = (arrest*100)/stops

gen agegroup = "Less Than 20"
replace agegroup = "20-24" if agerange==2 
replace agegroup = "25-29" if agerange==3
replace agegroup = "30-34" if agerange==4 
replace agegroup = "35-39" if agerange==5 
replace agegroup = "40-49" if agerange==6 
replace agegroup = "50+" if agerange==7 
replace agegroup = "" if RG4 ==.

gen RaceGender = "Hispanic Male"
replace RaceGender = "White Male" if RG4==2
replace RaceGender = "Hispanic Female" if RG4==3
replace RaceGender = "White Female" if RG4==4
replace RaceGender = "" if RG4==.

#delimit ;
graph bar searchrate, over(agegroup, sort(agerange) label(angle(90) labsize(vsmall)))  over(RaceGender, sort(RG4)) 
graphregion(color(white))
nofill
bar(1, color(black)) 
aspectratio() 
ylabel(, nogrid) 
ytitle("")
note("")
;
#delimit cr
graph export "Chap8_Fig2a_SearchRateByRaceGenderAge.png", width(1950) replace

#delimit ;
graph bar noactionrate, over(agegroup, sort(agerange) label(angle(90) labsize(vsmall)))  over(RaceGender, sort(RG4)) 
graphregion(color(white))
nofill
bar(1, color(black)) 
aspectratio() 
ylabel(, nogrid) 
ytitle("")
note("")
;
#delimit cr

graph export "Chap8_Fig2b_NoActionRateByRaceGenderAge.png", width(1950) replace

#delimit ;
graph bar verbalrate, over(agegroup, sort(agerange) label(angle(90) labsize(vsmall)))  over(RaceGender, sort(RG4)) 
graphregion(color(white))
nofill
bar(1, color(black)) 
aspectratio() 
ylabel(, nogrid) 
ytitle("")
note("")
;
#delimit cr

graph export "Chap8_Fig2c_VerbalRateByRaceGenderAge.png", width(1950) replace

#delimit ;
graph bar writtenrate, over(agegroup, sort(agerange) label(angle(90) labsize(vsmall)))  over(RaceGender, sort(RG4)) 
graphregion(color(white))
nofill
bar(1, color(black)) 
aspectratio() 
ylabel(, nogrid) 
ytitle("")
note("")
;
#delimit cr

graph export "Chap8_Fig2d_WrittenRateByRaceGenderAge.png", width(1950) replace

#delimit ;
graph bar citationrate, over(agegroup, sort(agerange) label(angle(90) labsize(vsmall)))  over(RaceGender, sort(RG4)) 
graphregion(color(white))
nofill
bar(1, color(black)) 
aspectratio() 
ylabel(, nogrid) 
ytitle("")
note("")
;
#delimit cr

graph export "Chap8_Fig2e_CitationRateByRaceGenderAge.png", width(1950) replace

#delimit ;
graph bar arrestrate, over(agegroup, sort(agerange) label(angle(90) labsize(vsmall)))  over(RaceGender, sort(RG4)) 
graphregion(color(white))
nofill
bar(1, color(black)) 
aspectratio() 
ylabel(, nogrid) 
ytitle("")
note("")
;
#delimit cr

graph export "Chap8_Fig2f_ArrestRateByRaceGenderAge.png", width(1950) replace

**
** Table 7.3 - Type of search by ethnicity 
** 

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

*rename SearchType searchtype
replace searchtype = . if searchoccur == 0 

*Searchtype: 1= consent, 2= warrant, 3= probable cause, 4= incident to arrest, 5= protective frisk

tab searchoccur
tab race2
tab race2 searchoccur, row

gen consent = 1 if searchtype == 1
replace consent = 0 if consent == . 
tab consent
tab race2 consent, row

gen warrant = 1 if searchtype == 2
replace warrant = 0 if warrant == . 
tab warrant 
tab race2 warrant, row

gen cause = 1 if searchtype == 3
replace cause = 0 if cause == . 
tab cause
tab race2 cause, row

gen arrest1 = 1 if searchtype == 4
replace arrest1 = 0 if arrest1 == . 
tab arrest1
tab race2 arrest1, row

gen frisk = 1 if searchtype == 5
replace frisk = 0 if frisk == . 
tab frisk
tab race2 frisk, row

**
** Table 7.4 - Percentage of searches that result in contraband 
** 

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"
replace contraoccur = . if contraoccur == 1 & searchoccur == 0 


replace searchtype = . if searchoccur == 0 

*Searchtype: 1= consent, 2= warrant, 3= probable cause, 4= incident to arrest, 5= protective frisk

tab searchoccur contraoccur, row
tab race2 contraoccur if searchoccur == 1, row

tab contraoccur if searchtype == 1
tab race2 contraoccur if searchtype == 1, row

tab contraoccur if searchtype == 2
tab race2 contraoccur if searchtype == 2, row

tab contraoccur if searchtype == 3
tab race2 contraoccur if searchtype == 3, row

tab contraoccur if searchtype == 4
tab race2 contraoccur if searchtype == 4, row

tab contraoccur if searchtype == 5
tab race2 contraoccur if searchtype == 5, row

**
** Figure 7.2 - Percent Difference in the Likelihood of Search and Contraband 
**

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

replace contraoccur = . if contraoccur == 1 & searchoccur == 0 


replace searchtype = . if searchoccur == 0 

gen whtconsent = 1 if searchtype == 1 & race2 == 1
replace whtconsent = 0 if whtconsent == . 

gen whtconsent_contra = 1 if whtconsent == 1 & contraoccur == 1
replace whtconsent_contra = 0 if whtconsent_contra == . 

gen whtcause = 1 if searchtype == 3 & race2 == 1
replace whtcause = 0 if whtcause == . 

gen whtcause_contra = 1 if whtcause == 1 & contraoccur == 1
replace whtcause_contra = 0 if whtcause_contra == . 

gen hspconsent = 1 if searchtype == 1 & race2 == 3
replace hspconsent = 0 if hspconsent == . 

gen hspconsent_contra = 1 if hspconsent == 1 & contraoccur == 1
replace hspconsent_contra = 0 if hspconsent_contra == . 

gen hspcause = 1 if searchtype == 3 & race2 == 3
replace hspcause = 0 if hspcause == . 

gen hspcause_contra = 1 if hspcause == 1 & contraoccur == 1
replace hspcause_contra = 0 if hspcause_contra == . 

gen white = 1 if race2 == 1
replace white = 0 if white == . 

gen hispanic = 1 if race2 == 3
replace hispanic = 0 if hispanic == . 

collapse (sum) whtconsent whtconsent_contra whtcause whtcause_contra hspconsent hspconsent_contra hspcause hspcause_contra white hispanic, by(year)

gen pctwhtconsent = (whtconsent/white)*100
gen pcthspconsent = (hspconsent/hispanic)*100
gen ratioconsent = (pcthspconsent/pctwhtconsent)*100
replace ratioconsent = ratioconsent-100

gen pctwhtcause = (whtcause/white)*100
gen pcthspcause = (hspcause/hispanic)*100
gen ratiocause = (pcthspcause/pctwhtcause)*100
replace ratiocause = ratiocause-100

gen pctwhtconsent_contra = (whtconsent_contra/whtconsent)*100
gen pcthspconsent_contra = (hspconsent_contra/hspconsent)*100
gen ratioconsent_contra = (pcthspconsent_contra/pctwhtconsent_contra)*100
replace ratioconsent_contra = ratioconsent_contra-100

gen pctwhtcause_contra = (whtcause_contra/whtcause)*100
gen pcthspcause_contra = (hspcause_contra/hspcause)*100
gen ratiocause_contra = (pcthspcause_contra/pctwhtcause_contra)*100
replace ratiocause_contra = ratiocause_contra-100

#delimit ;
twoway (line ratioconsent year, lwidth(thick) lcolor(black))
(line ratioconsent_contra year, lwidth(thick) lcolor(black) lpattern(dash) yaxis(2)),
graphregion(color(white))
ylabel(, nogrid)
ylabel(-60(20)0, axis(2))
xlabel(2002(2)2020)
ytitle(Percent Difference Search)
ytitle(Percent Difference Contraband, axis(2))
xtitle(Year)
legend(order(1 "Search Ratio" 2 "Contraband Hit Ratio"))
;
#delimit cr

graph export "Chapt8_Fig3a_SearchContraConsent.png", width(1950) replace

#delimit ;
twoway (line ratiocause year, lwidth(thick) lcolor(black))
(line ratiocause_contra year, lwidth(thick) lcolor(black) lpattern(dash) yaxis(2)),
graphregion(color(white))
ylabel(, nogrid)
ylabel(-40(10)0, axis(2))
ylabel(0(20)80)
xlabel(2002(2)2020)
ytitle(Percent Difference Search)
ytitle(Percent Difference Contraband, axis(2))
xtitle(Year)
legend(order(1 "Search Ratio" 2 "Contraband Hit Ratio"))
;
#delimit cr

graph export "Chapt8_Fig3b_SearchContraCause.png", width(1950) replace

**
** Figure 7.3 - White and Hispanic Search Rates Compared
**

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

*drop if stops_blk > 7000

gen invest = 1 if purpose == 5 | purpose == 6 | purpose == 7 | purpose == 8 | purpose == 9 

gen stops = 1
gen hsp_stop_invest = 1 if race2 == 3 & invest == 1
gen wht_stop_invest = 1 if race2 == 1 & invest == 1
gen hsp_search_invest = 1 if race2 == 3 & searchoccur == 1 & invest == 1
gen wht_search_invest = 1 if race2 == 1 & searchoccur == 1 & invest == 1
gen hsp_search = 1 if race2 == 3 & searchoccur == 1 
gen wht_search = 1 if race2 == 1 & searchoccur == 1 

collapse (sum) stops hsp_stop_invest wht_stop_invest hsp_search_invest wht_search_invest hsp_search wht_search, by (officerid)

drop if stops < 100
drop if hsp_search < 10
drop if wht_search < 10

reg wht_stop_invest hsp_stop_invest, noconst
gen stoprate=hsp_search_invest*3.89
reg wht_search_invest hsp_search_invest, noconst
gen wht_search_rate = hsp_search_invest*2.59
*hardcoded values updated

#delimit ;
twoway (scatter wht_search_invest hsp_search_invest, mcolor(black))
(scatter stoprate hsp_search_invest, connect(l) msymbol(none) lcolor(gs7) lwidth(medthick))
(scatter wht_search_rate hsp_search_invest , connect(l) msymbol(none) lcolor(gs7) lwidth(thin)),
ytitle(Whites Searched)
xtitle(Hispanics Searched)  
ylabel(, nogrid) 
graphregion(color(white)) 
legend(order(1 "Officer" 2 "Stop Rate" 3 "Search Rate"))
;
#delimit cr

graph export "Chapt8_Fig4a_OfficerSearch_Invest.png", width(1950) replace

clear
use "/nas/longleaf/home/ajlove/NC_TrafficStops_2002-2020_Clean.dta"

gen safety = 1 if purpose == 1 | purpose == 2 | purpose == 3 | purpose == 4  

gen stops = 1
gen hsp_stop_safety = 1 if race2 == 3 & safety == 1
gen wht_stop_safety = 1 if race2 == 1 & safety == 1
gen hsp_search_safety = 1 if race2 == 3 & searchoccur == 1 & safety == 1
gen wht_search_safety = 1 if race2 == 1 & searchoccur == 1 & safety == 1
gen hsp_search = 1 if race2 == 3 & searchoccur == 1 
gen wht_search = 1 if race2 == 1 & searchoccur == 1 

collapse (sum) stops hsp_stop_safety wht_stop_safety hsp_search wht_search wht_search_safety hsp_search_safety, by (officerid)

drop if stops < 100
drop if hsp_search < 10
drop if wht_search < 10

reg wht_stop_safety hsp_stop_safety, noconst
gen stoprate=hsp_search_safety*5.91
reg wht_search_safety hsp_search_safety, noconst
gen wht_search_rate = hsp_search_safety*1.46

#delimit ;
twoway (scatter wht_search_safety hsp_search_safety, mcolor(black))
(scatter stoprate hsp_search_safety if stoprate < 1000, connect(l) msymbol(none) lcolor(gs7) lwidth(medthick))
(scatter wht_search_rate hsp_search_safety , connect(l) msymbol(none) lcolor(gs7) lwidth(thin)),
ytitle(Whites Searched)
xtitle(Hispanics Searched)  
ylabel(0(250)1000, nogrid) 
graphregion(color(white)) 
legend(order(1 "Officer" 2 "Stop Rate" 3 "Search Rate"))
;

graph export "Chapt8_Fig4b_OfficerSearch_Safety.png", width(1950) replace

