cd "F:\TrafficStops\UpdatedBookChapters\Chapter8Cleaning"

set more off

log using "Chap8_23Oct2017.txt", t replace 


*****
*****
***** Municipal Police Departments
*****
*****

* Reading in the Data
clear
import delimited Analysis\MunicipalPoliticalData_22Oct2017.txt, delimiter(tab)  

encode clean_name, gen(encoded_name)

tsset encoded_name year

codebook pol_power invest_ratio pop_log crime_per_thousand below_poverty
replace crime_per_thousand = "" if crime_per_thousand == "NA"
destring crime_per_thousand, replace
replace dwb_a_10 = "" if dwb_a_10 == "NA"
destring dwb_a_10, replace


*
* Table 8.1: Summary Statistics (Municipal Departments)
*

sum search_ratio if crime_per_thousand != .,d
sum light_ratio if crime_per_thousand != .,d
sum cite_ratio if crime_per_thousand != .,d
sum arrest_ratio if crime_per_thousand != .,d
sum invest_ratio if crime_per_thousand != .,d

*
* Figure 8.1: Histogram of Poltiical Power (Muni)
* 

* Histogram
histogram pol_power, fcolor(black) lcolor(black) graphregion(color(white)) aspectratio() ylabel(, nogrid)  xtitle("Political Power") freq

* Exporting as a PNG
graph export Figures_PNG\Figure8_1.png, width(1950) replace

* Exporting as a EPS
graph export Figures_EPS\Figure8_1.eps, replace

*
* Searches Regression & Figures (Table 8.2a, Figure 8.2a, Figure 8.3a)
*

* Search Ratio Regression
xtreg search_ratio pol_power invest_ratio pop_log crime_per_thousand below_poverty 

* Search Ratio Marginal Plot (POLITICAL POWER)
margins, at(pol_power=(-1.25(.05)3))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Search Ratio") xtitle("Political Power") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_2a.png, width(1950) replace
graph export Figures_EPS\Figure8_2a.eps, replace

* Search Ratio Marginal Plot (INVESTIGATORY STOPS)
margins, at(invest_ratio=(0.5(.05)2))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Search Ratio") xtitle("Investigatory Stops Ratio") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_3a.png, width(1950) replace
graph export Figures_EPS\Figure8_3a.eps, replace

*
* Light Outcomes Regression & Figures (Table 8.2a, Figure 8.2a, Figure 8.3a)
*

* Search Ratio Regression
xtreg light_ratio pol_power invest_ratio pop_log crime_per_thousand below_poverty 

* Search Ratio Marginal Plot (POLITICAL POWER)
margins, at(pol_power=(-1.25(.05)3))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Light Outcomes Ratio") xtitle("Political Power") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_2b.png, width(1950) replace
graph export Figures_EPS\Figure8_2b.eps, replace

* Search Ratio Marginal Plot (INVESTIGATORY STOPS)
margins, at(invest_ratio=(0.5(.05)2))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Light Outcomes Ratio") xtitle("Investigatory Stops Ratio") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_3b.png, width(1950) replace
graph export Figures_EPS\Figure8_3b.eps, replace


*
* Citations Regression & Figures (Table 8.2a, Figure 8.2a, Figure 8.3a)
*

* Search Ratio Regression
xtreg cite_ratio pol_power invest_ratio pop_log crime_per_thousand below_poverty 

* Search Ratio Marginal Plot (POLITICAL POWER)
margins, at(pol_power=(-1.25(.05)3))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Citations Ratio") xtitle("Political Power") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_2c.png, width(1950) replace
graph export Figures_EPS\Figure8_2c.eps, replace

* Search Ratio Marginal Plot (INVESTIGATORY STOPS)
margins, at(invest_ratio=(0.5(.05)2))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Citations Ratio") xtitle("Investigatory Stops Ratio") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_3c.png, width(1950) replace
graph export Figures_EPS\Figure8_3c.eps, replace


*
* Citations Regression & Figures (Table 8.2a, Figure 8.2a, Figure 8.3a)
*

* Search Ratio Regression
xtreg arrest_ratio pol_power invest_ratio pop_log crime_per_thousand below_poverty 

* Search Ratio Marginal Plot (POLITICAL POWER)
margins, at(pol_power=(-1.25(.05)3))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Arrest Ratio") xtitle("Political Power") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_2d.png, width(1950) replace
graph export Figures_EPS\Figure8_2d.eps, replace

* Search Ratio Marginal Plot (INVESTIGATORY STOPS)
margins, at(invest_ratio=(0.5(.05)2))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Arrest Ratio") xtitle("Investigatory Stops Ratio") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_3d.png, width(1950) replace
graph export Figures_EPS\Figure8_3d.eps, replace


*****
*****
***** County Sherriff Departments
*****
*****

* Reading in the Data
clear
import delimited Analysis\SheriffPoliticalData_22Oct2017.txt, delimiter(tab)  

encode clean_name, gen(encoded_name)

tsset encoded_name year

replace party = "" if party == "NA"
destring party, replace
gen republican = party - 1

*
* Table 8.3: Summary Statistics (Municipal Departments)
*

sum search_ratio,d
sum light_ratio,d
sum cite_ratio,d
sum arrest_ratio,d
sum invest_ratio,d

*
* Figure 8.4: Histogram of Poltiical Power (Muni)
* 

* Histogram
histogram pol_power, fcolor(black) lcolor(black) graphregion(color(white)) aspectratio() ylabel(, nogrid)  xtitle("Political Power") freq

graph export Figures_PNG\Figure8_4.png, width(1950) replace
graph export Figures_EPS\Figure8_4.eps, replace


*
* Searches Regression & Figures (Table 8.2a, Figure 8.2a, Figure 8.3a)
*

* Regression
xtreg search_ratio pol_power invest_ratio republican pop_log   

* Search Ratio Marginal Plot (POLITICAL POWER)
margins, at(pol_power=(-1.25(.05)3))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Search Ratio") xtitle("Political Power") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_5a.png, width(1950) replace
graph export Figures_EPS\Figure8_5a.eps, replace

* Search Ratio Marginal Plot (INVESTIGATORY STOPS)
margins, at(invest_ratio=(0.5(.05)2))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Search Ratio") xtitle("Investigatory Stops Ratio") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_6a.png, width(1950) replace
graph export Figures_EPS\Figure8_6a.eps, replace

*
* Light Outcomes Regression & Figures (Table 8.2a, Figure 8.2a, Figure 8.3a)
*

* Regression
xtreg light_ratio pol_power invest_ratio republican pop_log    

* Search Ratio Marginal Plot (POLITICAL POWER)
margins, at(pol_power=(-1.25(.05)3))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Light Outcomes Ratio") xtitle("Political Power") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_5b.png, width(1950) replace
graph export Figures_EPS\Figure8_5b.eps, replace

* Search Ratio Marginal Plot (INVESTIGATORY STOPS)
margins, at(invest_ratio=(0.5(.05)2))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Light Outcomes Ratio") xtitle("Investigatory Stops Ratio") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_6b.png, width(1950) replace
graph export Figures_EPS\Figure8_6b.eps, replace


*
* Citations Regression & Figures (Table 8.2a, Figure 8.2a, Figure 8.3a)
*

* Search Ratio Regression
xtreg cite_ratio pol_power invest_ratio republican pop_log    

* Search Ratio Marginal Plot (POLITICAL POWER)
margins, at(pol_power=(-1.25(.05)3))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Citations Ratio") xtitle("Political Power") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_5c.png, width(1950) replace
graph export Figures_EPS\Figure8_5c.eps, replace

* Search Ratio Marginal Plot (INVESTIGATORY STOPS)
margins, at(invest_ratio=(0.5(.05)2))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Citations Ratio") xtitle("Investigatory Stops Ratio") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_6c.png, width(1950) replace
graph export Figures_EPS\Figure8_6c.eps, replace


*
* Citations Regression & Figures (Table 8.2a, Figure 8.2a, Figure 8.3a)
*

* Search Ratio Regression
xtreg arrest_ratio pol_power invest_ratio republican pop_log    

* Search Ratio Marginal Plot (POLITICAL POWER)
margins, at(pol_power=(-1.25(.05)3))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Arrest Ratio") xtitle("Political Power") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_5d.png, width(1950) replace
graph export Figures_EPS\Figure8_5d.eps, replace

* Search Ratio Marginal Plot (INVESTIGATORY STOPS)
margins, at(invest_ratio=(0.5(.05)2))
marginsplot, scheme(sj) graphregion(color(white)) aspectratio() ylabel(, nogrid) title("") ytitle("Expected Arrest Ratio") xtitle("Investigatory Stops Ratio") recast(line) recastci(rline) yline(1,lcolor(gs11) lpattern(dash))

graph export Figures_PNG\Figure8_6d.png, width(1950) replace
graph export Figures_EPS\Figure8_6d.eps, replace


****************************************************************************************
****************************************************************************************
****************************************************************************************

log close
